#!/bin/sh -e
#
# InstallWeeWX
#
# Script to install WeeWX and a few extensions.

# WeeWX prerequisites:

sudo apt update

# Required:

sudo apt-get -y install python3-configobj
sudo apt-get -y install python3-pil
sudo apt-get -y install python3-serial
sudo apt-get -y install python3-usb
sudo apt-get -y install python3-pip

# This works for most installations:

sudo apt install python3-cheetah

# Optional: for extended almanac information.

sudo apt install python3-ephem

#   WeeWX itself:

cd /home/pi/Downloads
tar xvfz weewx-4.4.0.tar.gz
cd weewx-4.4.0
python3 ./setup.py build

# Answers to installation question must be in an external file.
#
#   Order of questions:
#    Station Name: Some Name
#    Elevation with units: 0, foot
#    Latitude: 49
#    Longitude: -119
#    Include in station listing: n
#    Units: metric
#    Driver: 3 is Simulator
#
#   Use cat "FileWithAnswers" | ./ThisScript to run this script 
#   with an answer file.

sudo python3 ./setup.py install

# WeeWX extensions:

cd /home/pi/Downloads

# WeatherFlowUDP:

sudo /home/weewx/bin/wee_extension --install weatherflow-udp-master.zip

# Belchertown skin:

sudo /home/weewx/bin/wee_extension --install weewx-belchertown-master.zip

# MQTT:

sudo pip3 install paho-mqtt
sudo /home/weewx/bin/wee_extension --install weewx-mqtt-master.zip

# mem extension:

sudo /home/weewx/bin/wee_extension --install vds-weewx-v3-mem-extension-master.zip

# WXFeeds tmpfs.

echo "WXFeeds /WXFeeds tmpfs size=100M,noexec,nosuid 0 0" | sudo tee -a /etc/fstab
sudo mkdir -p /WXFeeds
sudo mount -a

# WXFeeds:

sudo pip3 install feedparser
sudo pip3 install python-dateutil
sudo pip3 install pytz
sudo pip3 install isodate
sudo pip3 install polyline
sudo pip3 install haversine

sudo /home/weewx/bin/wee_extension --install WXFeeds-main.zip

# WeeWX startup:

cd /home/weewx
sudo cp util/init.d/weewx.debian /etc/init.d/weewx
sudo chmod +x /etc/init.d/weewx
sudo update-rc.d weewx defaults 98
sudo /etc/init.d/weewx start

exit 0