# install.py - installer for the WXFeeds - a WeeWx service extension.
# Copyright 2020-2099 Garry Lockyer - Garry@lockyer.ca.
# Distributed under the terms of the GNU Public License (GPLv3).

from setup import ExtensionInstaller

def loader():
    return WXFeedsInstaller()

class WXFeedsInstaller(ExtensionInstaller):
    def __init__(self):
        super(WXFeedsInstaller, self).__init__(
            version="0.05",
            name='WXFeeds',
            description='WeeWX Service extension to access numerous RSS/Atom/XML Feeds',
            author="Garry Lockyer",
            author_email="Garry@lockyer.ca",
            config= {
                      'Engine': {
                                  'Services': {
                                                '# Add to existing report_services: user.WXFeeds.WXFeeds',
                                                '# Standard Entry: report_services = weewx.engine.StdPrint, weewx.engine.StdReport',
                                                '# Possible edited entries:',
                                                '# report_services = weewx.engine.StdPrint, weewx.engine.StdReport, user.WXFeeds.WXFeeds or',
                                                '# report_services = weewx.engine.StdPrint, user.WXFeeds.WXFeeds, weewx.engine.StdReport'
                                              },
                                },
                      'WXFeeds': {
                                   'Setup' : {
                                               'Reports' : {
                                                             'Belchertown' : {
                                                                               'custom_css_path': 'custom.css',
                                                                               'disable_WXFeeds_css': 'no',
                                                                               'filenames_to_delete': 'index_hook_after_station_info.inc',
                                                                               'add_back_to_top_button': 'yes',
                                                                               'cheetah_memory_leak_workaround' : 'yes'
                                                                             }
                                                           }
                                             },
                                   'Feeds' : {
                                               'Environment Canada': {
                                                                       'Citys': {
                                                                                  'alerts_first': 'yes',
                                                                                  'inline_forecast': 'yes',
                                                                                  'get_weather': 'yes',
                                                                                  'get_alerts': 'no',
                                                                                        
                                                                                   'Osoyoos, BC': {
                                                                                                    'feed_url': 'https://weather.gc.ca/rss/city/bc-69_e.xml'
                                                                                                  }
                                                                                 },
                                                                     },
                                             },
                                 },
                      'Logging': {
                                   'loggers': {
                                                'user.WXFeeds': {
                                                                  'level': 'WARNING',
                                                                  'handlers': 'syslog',
                                                                  'propagate': '0'
                                                                }
                                              }
                                 }
                    },
            files=[
                    (
                      'bin/user', 
                      [
                        'bin/user/WXFeeds.py'
                        'bin/user/extensions.py-WXFeeds'
                      ]
                    ),
                    (
                      'skins',
                      [
                        'docs/WXFeeds-READ-ME',
                        'docs/WXFeeds-Sample-weewx.conf'
                      ]
                    ),
                    (
                      'skins/Belchertown/images',
                      [
                        'skins/Belchertown/images/WXFeeds-checklist.png',
                        'skins/Belchertown/images/WXFeeds-current-planned-cone.png',
                        'skins/Belchertown/images/WXFeeds-future-planned-cone.png',
                        'skins/Belchertown/images/WXFeeds-google-map.png',
                        'skins/Belchertown/images/WXFeeds-incident.png',
                        'skins/Belchertown/images/WXFeeds-map.png',
                        'skins/Belchertown/images/WXFeeds-map-marker.png',
                        'skins/Belchertown/images/WXFeeds-play.png',
                        'skins/Belchertown/images/WXFeeds-refresh.png',
                        'skins/Belchertown/images/WXFeeds-road-condition.png',
                        'skins/Belchertown/images/WXFeeds-warning-sign.png',
                        'skins/Belchertown/images/WXFeeds-weather-station.png'
                      ]
                    )
                  ]
        )

